# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    cast as typing___cast,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.duration_pb2 import (
    Duration as google___protobuf___duration_pb2___Duration,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry,
    PolicyViolationKey as google___ads___googleads___v6___common___policy_pb2___PolicyViolationKey,
)
from google.ads.google_ads.v6.proto.common.value_pb2 import (
    Value as google___ads___googleads___v6___common___value_pb2___Value,
)
from google.ads.google_ads.v6.proto.errors.access_invitation_error_pb2 import (
    AccessInvitationErrorEnum as google___ads___googleads___v6___errors___access_invitation_error_pb2___AccessInvitationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.account_budget_proposal_error_pb2 import (
    AccountBudgetProposalErrorEnum as google___ads___googleads___v6___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.account_link_error_pb2 import (
    AccountLinkErrorEnum as google___ads___googleads___v6___errors___account_link_error_pb2___AccountLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_customizer_error_pb2 import (
    AdCustomizerErrorEnum as google___ads___googleads___v6___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_error_pb2 import (
    AdErrorEnum as google___ads___googleads___v6___errors___ad_error_pb2___AdErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_group_ad_error_pb2 import (
    AdGroupAdErrorEnum as google___ads___googleads___v6___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_group_bid_modifier_error_pb2 import (
    AdGroupBidModifierErrorEnum as google___ads___googleads___v6___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_group_criterion_error_pb2 import (
    AdGroupCriterionErrorEnum as google___ads___googleads___v6___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_group_error_pb2 import (
    AdGroupErrorEnum as google___ads___googleads___v6___errors___ad_group_error_pb2___AdGroupErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_group_feed_error_pb2 import (
    AdGroupFeedErrorEnum as google___ads___googleads___v6___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_parameter_error_pb2 import (
    AdParameterErrorEnum as google___ads___googleads___v6___errors___ad_parameter_error_pb2___AdParameterErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.ad_sharing_error_pb2 import (
    AdSharingErrorEnum as google___ads___googleads___v6___errors___ad_sharing_error_pb2___AdSharingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.adx_error_pb2 import (
    AdxErrorEnum as google___ads___googleads___v6___errors___adx_error_pb2___AdxErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.asset_error_pb2 import (
    AssetErrorEnum as google___ads___googleads___v6___errors___asset_error_pb2___AssetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.asset_link_error_pb2 import (
    AssetLinkErrorEnum as google___ads___googleads___v6___errors___asset_link_error_pb2___AssetLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.authentication_error_pb2 import (
    AuthenticationErrorEnum as google___ads___googleads___v6___errors___authentication_error_pb2___AuthenticationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.authorization_error_pb2 import (
    AuthorizationErrorEnum as google___ads___googleads___v6___errors___authorization_error_pb2___AuthorizationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.batch_job_error_pb2 import (
    BatchJobErrorEnum as google___ads___googleads___v6___errors___batch_job_error_pb2___BatchJobErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.bidding_error_pb2 import (
    BiddingErrorEnum as google___ads___googleads___v6___errors___bidding_error_pb2___BiddingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.bidding_strategy_error_pb2 import (
    BiddingStrategyErrorEnum as google___ads___googleads___v6___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.billing_setup_error_pb2 import (
    BillingSetupErrorEnum as google___ads___googleads___v6___errors___billing_setup_error_pb2___BillingSetupErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_budget_error_pb2 import (
    CampaignBudgetErrorEnum as google___ads___googleads___v6___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_criterion_error_pb2 import (
    CampaignCriterionErrorEnum as google___ads___googleads___v6___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_draft_error_pb2 import (
    CampaignDraftErrorEnum as google___ads___googleads___v6___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_error_pb2 import (
    CampaignErrorEnum as google___ads___googleads___v6___errors___campaign_error_pb2___CampaignErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_experiment_error_pb2 import (
    CampaignExperimentErrorEnum as google___ads___googleads___v6___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_feed_error_pb2 import (
    CampaignFeedErrorEnum as google___ads___googleads___v6___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.campaign_shared_set_error_pb2 import (
    CampaignSharedSetErrorEnum as google___ads___googleads___v6___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.change_event_error_pb2 import (
    ChangeEventErrorEnum as google___ads___googleads___v6___errors___change_event_error_pb2___ChangeEventErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.change_status_error_pb2 import (
    ChangeStatusErrorEnum as google___ads___googleads___v6___errors___change_status_error_pb2___ChangeStatusErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.collection_size_error_pb2 import (
    CollectionSizeErrorEnum as google___ads___googleads___v6___errors___collection_size_error_pb2___CollectionSizeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.context_error_pb2 import (
    ContextErrorEnum as google___ads___googleads___v6___errors___context_error_pb2___ContextErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.conversion_action_error_pb2 import (
    ConversionActionErrorEnum as google___ads___googleads___v6___errors___conversion_action_error_pb2___ConversionActionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.conversion_adjustment_upload_error_pb2 import (
    ConversionAdjustmentUploadErrorEnum as google___ads___googleads___v6___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.conversion_upload_error_pb2 import (
    ConversionUploadErrorEnum as google___ads___googleads___v6___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.country_code_error_pb2 import (
    CountryCodeErrorEnum as google___ads___googleads___v6___errors___country_code_error_pb2___CountryCodeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.criterion_error_pb2 import (
    CriterionErrorEnum as google___ads___googleads___v6___errors___criterion_error_pb2___CriterionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.currency_code_error_pb2 import (
    CurrencyCodeErrorEnum as google___ads___googleads___v6___errors___currency_code_error_pb2___CurrencyCodeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.custom_audience_error_pb2 import (
    CustomAudienceErrorEnum as google___ads___googleads___v6___errors___custom_audience_error_pb2___CustomAudienceErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.custom_interest_error_pb2 import (
    CustomInterestErrorEnum as google___ads___googleads___v6___errors___custom_interest_error_pb2___CustomInterestErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.customer_client_link_error_pb2 import (
    CustomerClientLinkErrorEnum as google___ads___googleads___v6___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.customer_error_pb2 import (
    CustomerErrorEnum as google___ads___googleads___v6___errors___customer_error_pb2___CustomerErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.customer_feed_error_pb2 import (
    CustomerFeedErrorEnum as google___ads___googleads___v6___errors___customer_feed_error_pb2___CustomerFeedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.customer_manager_link_error_pb2 import (
    CustomerManagerLinkErrorEnum as google___ads___googleads___v6___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.customer_user_access_error_pb2 import (
    CustomerUserAccessErrorEnum as google___ads___googleads___v6___errors___customer_user_access_error_pb2___CustomerUserAccessErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.database_error_pb2 import (
    DatabaseErrorEnum as google___ads___googleads___v6___errors___database_error_pb2___DatabaseErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.date_error_pb2 import (
    DateErrorEnum as google___ads___googleads___v6___errors___date_error_pb2___DateErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.date_range_error_pb2 import (
    DateRangeErrorEnum as google___ads___googleads___v6___errors___date_range_error_pb2___DateRangeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.distinct_error_pb2 import (
    DistinctErrorEnum as google___ads___googleads___v6___errors___distinct_error_pb2___DistinctErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.enum_error_pb2 import (
    EnumErrorEnum as google___ads___googleads___v6___errors___enum_error_pb2___EnumErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.extension_feed_item_error_pb2 import (
    ExtensionFeedItemErrorEnum as google___ads___googleads___v6___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.extension_setting_error_pb2 import (
    ExtensionSettingErrorEnum as google___ads___googleads___v6___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_attribute_reference_error_pb2 import (
    FeedAttributeReferenceErrorEnum as google___ads___googleads___v6___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_error_pb2 import (
    FeedErrorEnum as google___ads___googleads___v6___errors___feed_error_pb2___FeedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_item_error_pb2 import (
    FeedItemErrorEnum as google___ads___googleads___v6___errors___feed_item_error_pb2___FeedItemErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_item_set_error_pb2 import (
    FeedItemSetErrorEnum as google___ads___googleads___v6___errors___feed_item_set_error_pb2___FeedItemSetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_item_set_link_error_pb2 import (
    FeedItemSetLinkErrorEnum as google___ads___googleads___v6___errors___feed_item_set_link_error_pb2___FeedItemSetLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_item_target_error_pb2 import (
    FeedItemTargetErrorEnum as google___ads___googleads___v6___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_item_validation_error_pb2 import (
    FeedItemValidationErrorEnum as google___ads___googleads___v6___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.feed_mapping_error_pb2 import (
    FeedMappingErrorEnum as google___ads___googleads___v6___errors___feed_mapping_error_pb2___FeedMappingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.field_error_pb2 import (
    FieldErrorEnum as google___ads___googleads___v6___errors___field_error_pb2___FieldErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.field_mask_error_pb2 import (
    FieldMaskErrorEnum as google___ads___googleads___v6___errors___field_mask_error_pb2___FieldMaskErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.function_error_pb2 import (
    FunctionErrorEnum as google___ads___googleads___v6___errors___function_error_pb2___FunctionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.function_parsing_error_pb2 import (
    FunctionParsingErrorEnum as google___ads___googleads___v6___errors___function_parsing_error_pb2___FunctionParsingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.geo_target_constant_suggestion_error_pb2 import (
    GeoTargetConstantSuggestionErrorEnum as google___ads___googleads___v6___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.header_error_pb2 import (
    HeaderErrorEnum as google___ads___googleads___v6___errors___header_error_pb2___HeaderErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.id_error_pb2 import (
    IdErrorEnum as google___ads___googleads___v6___errors___id_error_pb2___IdErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.image_error_pb2 import (
    ImageErrorEnum as google___ads___googleads___v6___errors___image_error_pb2___ImageErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.internal_error_pb2 import (
    InternalErrorEnum as google___ads___googleads___v6___errors___internal_error_pb2___InternalErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.invoice_error_pb2 import (
    InvoiceErrorEnum as google___ads___googleads___v6___errors___invoice_error_pb2___InvoiceErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_ad_group_error_pb2 import (
    KeywordPlanAdGroupErrorEnum as google___ads___googleads___v6___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_ad_group_keyword_error_pb2 import (
    KeywordPlanAdGroupKeywordErrorEnum as google___ads___googleads___v6___errors___keyword_plan_ad_group_keyword_error_pb2___KeywordPlanAdGroupKeywordErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_campaign_error_pb2 import (
    KeywordPlanCampaignErrorEnum as google___ads___googleads___v6___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_campaign_keyword_error_pb2 import (
    KeywordPlanCampaignKeywordErrorEnum as google___ads___googleads___v6___errors___keyword_plan_campaign_keyword_error_pb2___KeywordPlanCampaignKeywordErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_error_pb2 import (
    KeywordPlanErrorEnum as google___ads___googleads___v6___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.keyword_plan_idea_error_pb2 import (
    KeywordPlanIdeaErrorEnum as google___ads___googleads___v6___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.label_error_pb2 import (
    LabelErrorEnum as google___ads___googleads___v6___errors___label_error_pb2___LabelErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.language_code_error_pb2 import (
    LanguageCodeErrorEnum as google___ads___googleads___v6___errors___language_code_error_pb2___LanguageCodeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.list_operation_error_pb2 import (
    ListOperationErrorEnum as google___ads___googleads___v6___errors___list_operation_error_pb2___ListOperationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.manager_link_error_pb2 import (
    ManagerLinkErrorEnum as google___ads___googleads___v6___errors___manager_link_error_pb2___ManagerLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.media_bundle_error_pb2 import (
    MediaBundleErrorEnum as google___ads___googleads___v6___errors___media_bundle_error_pb2___MediaBundleErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.media_file_error_pb2 import (
    MediaFileErrorEnum as google___ads___googleads___v6___errors___media_file_error_pb2___MediaFileErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.media_upload_error_pb2 import (
    MediaUploadErrorEnum as google___ads___googleads___v6___errors___media_upload_error_pb2___MediaUploadErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.multiplier_error_pb2 import (
    MultiplierErrorEnum as google___ads___googleads___v6___errors___multiplier_error_pb2___MultiplierErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.mutate_error_pb2 import (
    MutateErrorEnum as google___ads___googleads___v6___errors___mutate_error_pb2___MutateErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.new_resource_creation_error_pb2 import (
    NewResourceCreationErrorEnum as google___ads___googleads___v6___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.not_allowlisted_error_pb2 import (
    NotAllowlistedErrorEnum as google___ads___googleads___v6___errors___not_allowlisted_error_pb2___NotAllowlistedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.not_empty_error_pb2 import (
    NotEmptyErrorEnum as google___ads___googleads___v6___errors___not_empty_error_pb2___NotEmptyErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.null_error_pb2 import (
    NullErrorEnum as google___ads___googleads___v6___errors___null_error_pb2___NullErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.offline_user_data_job_error_pb2 import (
    OfflineUserDataJobErrorEnum as google___ads___googleads___v6___errors___offline_user_data_job_error_pb2___OfflineUserDataJobErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.operation_access_denied_error_pb2 import (
    OperationAccessDeniedErrorEnum as google___ads___googleads___v6___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.operator_error_pb2 import (
    OperatorErrorEnum as google___ads___googleads___v6___errors___operator_error_pb2___OperatorErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.partial_failure_error_pb2 import (
    PartialFailureErrorEnum as google___ads___googleads___v6___errors___partial_failure_error_pb2___PartialFailureErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.payments_account_error_pb2 import (
    PaymentsAccountErrorEnum as google___ads___googleads___v6___errors___payments_account_error_pb2___PaymentsAccountErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.policy_finding_error_pb2 import (
    PolicyFindingErrorEnum as google___ads___googleads___v6___errors___policy_finding_error_pb2___PolicyFindingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.policy_validation_parameter_error_pb2 import (
    PolicyValidationParameterErrorEnum as google___ads___googleads___v6___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.policy_violation_error_pb2 import (
    PolicyViolationErrorEnum as google___ads___googleads___v6___errors___policy_violation_error_pb2___PolicyViolationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.query_error_pb2 import (
    QueryErrorEnum as google___ads___googleads___v6___errors___query_error_pb2___QueryErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.quota_error_pb2 import (
    QuotaErrorEnum as google___ads___googleads___v6___errors___quota_error_pb2___QuotaErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.range_error_pb2 import (
    RangeErrorEnum as google___ads___googleads___v6___errors___range_error_pb2___RangeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.reach_plan_error_pb2 import (
    ReachPlanErrorEnum as google___ads___googleads___v6___errors___reach_plan_error_pb2___ReachPlanErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.recommendation_error_pb2 import (
    RecommendationErrorEnum as google___ads___googleads___v6___errors___recommendation_error_pb2___RecommendationErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.region_code_error_pb2 import (
    RegionCodeErrorEnum as google___ads___googleads___v6___errors___region_code_error_pb2___RegionCodeErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.request_error_pb2 import (
    RequestErrorEnum as google___ads___googleads___v6___errors___request_error_pb2___RequestErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.resource_access_denied_error_pb2 import (
    ResourceAccessDeniedErrorEnum as google___ads___googleads___v6___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.resource_count_limit_exceeded_error_pb2 import (
    ResourceCountLimitExceededErrorEnum as google___ads___googleads___v6___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.setting_error_pb2 import (
    SettingErrorEnum as google___ads___googleads___v6___errors___setting_error_pb2___SettingErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.shared_criterion_error_pb2 import (
    SharedCriterionErrorEnum as google___ads___googleads___v6___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.shared_set_error_pb2 import (
    SharedSetErrorEnum as google___ads___googleads___v6___errors___shared_set_error_pb2___SharedSetErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.size_limit_error_pb2 import (
    SizeLimitErrorEnum as google___ads___googleads___v6___errors___size_limit_error_pb2___SizeLimitErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.string_format_error_pb2 import (
    StringFormatErrorEnum as google___ads___googleads___v6___errors___string_format_error_pb2___StringFormatErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.string_length_error_pb2 import (
    StringLengthErrorEnum as google___ads___googleads___v6___errors___string_length_error_pb2___StringLengthErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.third_party_app_analytics_link_error_pb2 import (
    ThirdPartyAppAnalyticsLinkErrorEnum as google___ads___googleads___v6___errors___third_party_app_analytics_link_error_pb2___ThirdPartyAppAnalyticsLinkErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.time_zone_error_pb2 import (
    TimeZoneErrorEnum as google___ads___googleads___v6___errors___time_zone_error_pb2___TimeZoneErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.url_field_error_pb2 import (
    UrlFieldErrorEnum as google___ads___googleads___v6___errors___url_field_error_pb2___UrlFieldErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.user_data_error_pb2 import (
    UserDataErrorEnum as google___ads___googleads___v6___errors___user_data_error_pb2___UserDataErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.user_list_error_pb2 import (
    UserListErrorEnum as google___ads___googleads___v6___errors___user_list_error_pb2___UserListErrorEnum,
)
from google.ads.google_ads.v6.proto.errors.youtube_video_registration_error_pb2 import (
    YoutubeVideoRegistrationErrorEnum as google___ads___googleads___v6___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GoogleAdsFailure(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def errors(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___GoogleAdsError
    ]: ...
    def __init__(
        self,
        *,
        errors: typing___Optional[typing___Iterable[type___GoogleAdsError]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["errors", b"errors"]
    ) -> None: ...

type___GoogleAdsFailure = GoogleAdsFailure

class GoogleAdsError(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    message: typing___Text = ...
    @property
    def error_code(self) -> type___ErrorCode: ...
    @property
    def trigger(self) -> google___ads___googleads___v6___common___value_pb2___Value: ...
    @property
    def location(self) -> type___ErrorLocation: ...
    @property
    def details(self) -> type___ErrorDetails: ...
    def __init__(
        self,
        *,
        error_code: typing___Optional[type___ErrorCode] = None,
        message: typing___Optional[typing___Text] = None,
        trigger: typing___Optional[
            google___ads___googleads___v6___common___value_pb2___Value
        ] = None,
        location: typing___Optional[type___ErrorLocation] = None,
        details: typing___Optional[type___ErrorDetails] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "trigger",
            b"trigger",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "message",
            b"message",
            "trigger",
            b"trigger",
        ],
    ) -> None: ...

type___GoogleAdsError = GoogleAdsError

class ErrorCode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    request_error: google___ads___googleads___v6___errors___request_error_pb2___RequestErrorEnum.RequestErrorValue = ...
    bidding_strategy_error: google___ads___googleads___v6___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum.BiddingStrategyErrorValue = ...
    url_field_error: google___ads___googleads___v6___errors___url_field_error_pb2___UrlFieldErrorEnum.UrlFieldErrorValue = ...
    list_operation_error: google___ads___googleads___v6___errors___list_operation_error_pb2___ListOperationErrorEnum.ListOperationErrorValue = ...
    query_error: google___ads___googleads___v6___errors___query_error_pb2___QueryErrorEnum.QueryErrorValue = ...
    mutate_error: google___ads___googleads___v6___errors___mutate_error_pb2___MutateErrorEnum.MutateErrorValue = ...
    field_mask_error: google___ads___googleads___v6___errors___field_mask_error_pb2___FieldMaskErrorEnum.FieldMaskErrorValue = ...
    authorization_error: google___ads___googleads___v6___errors___authorization_error_pb2___AuthorizationErrorEnum.AuthorizationErrorValue = ...
    internal_error: google___ads___googleads___v6___errors___internal_error_pb2___InternalErrorEnum.InternalErrorValue = ...
    quota_error: google___ads___googleads___v6___errors___quota_error_pb2___QuotaErrorEnum.QuotaErrorValue = ...
    ad_error: google___ads___googleads___v6___errors___ad_error_pb2___AdErrorEnum.AdErrorValue = ...
    ad_group_error: google___ads___googleads___v6___errors___ad_group_error_pb2___AdGroupErrorEnum.AdGroupErrorValue = ...
    campaign_budget_error: google___ads___googleads___v6___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum.CampaignBudgetErrorValue = ...
    campaign_error: google___ads___googleads___v6___errors___campaign_error_pb2___CampaignErrorEnum.CampaignErrorValue = ...
    authentication_error: google___ads___googleads___v6___errors___authentication_error_pb2___AuthenticationErrorEnum.AuthenticationErrorValue = ...
    ad_group_criterion_error: google___ads___googleads___v6___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue = ...
    ad_customizer_error: google___ads___googleads___v6___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum.AdCustomizerErrorValue = ...
    ad_group_ad_error: google___ads___googleads___v6___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum.AdGroupAdErrorValue = ...
    ad_sharing_error: google___ads___googleads___v6___errors___ad_sharing_error_pb2___AdSharingErrorEnum.AdSharingErrorValue = ...
    adx_error: google___ads___googleads___v6___errors___adx_error_pb2___AdxErrorEnum.AdxErrorValue = ...
    asset_error: google___ads___googleads___v6___errors___asset_error_pb2___AssetErrorEnum.AssetErrorValue = ...
    bidding_error: google___ads___googleads___v6___errors___bidding_error_pb2___BiddingErrorEnum.BiddingErrorValue = ...
    campaign_criterion_error: google___ads___googleads___v6___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum.CampaignCriterionErrorValue = ...
    collection_size_error: google___ads___googleads___v6___errors___collection_size_error_pb2___CollectionSizeErrorEnum.CollectionSizeErrorValue = ...
    country_code_error: google___ads___googleads___v6___errors___country_code_error_pb2___CountryCodeErrorEnum.CountryCodeErrorValue = ...
    criterion_error: google___ads___googleads___v6___errors___criterion_error_pb2___CriterionErrorEnum.CriterionErrorValue = ...
    customer_error: google___ads___googleads___v6___errors___customer_error_pb2___CustomerErrorEnum.CustomerErrorValue = ...
    date_error: google___ads___googleads___v6___errors___date_error_pb2___DateErrorEnum.DateErrorValue = ...
    date_range_error: google___ads___googleads___v6___errors___date_range_error_pb2___DateRangeErrorEnum.DateRangeErrorValue = ...
    distinct_error: google___ads___googleads___v6___errors___distinct_error_pb2___DistinctErrorEnum.DistinctErrorValue = ...
    feed_attribute_reference_error: google___ads___googleads___v6___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum.FeedAttributeReferenceErrorValue = ...
    function_error: google___ads___googleads___v6___errors___function_error_pb2___FunctionErrorEnum.FunctionErrorValue = ...
    function_parsing_error: google___ads___googleads___v6___errors___function_parsing_error_pb2___FunctionParsingErrorEnum.FunctionParsingErrorValue = ...
    id_error: google___ads___googleads___v6___errors___id_error_pb2___IdErrorEnum.IdErrorValue = ...
    image_error: google___ads___googleads___v6___errors___image_error_pb2___ImageErrorEnum.ImageErrorValue = ...
    language_code_error: google___ads___googleads___v6___errors___language_code_error_pb2___LanguageCodeErrorEnum.LanguageCodeErrorValue = ...
    media_bundle_error: google___ads___googleads___v6___errors___media_bundle_error_pb2___MediaBundleErrorEnum.MediaBundleErrorValue = ...
    media_upload_error: google___ads___googleads___v6___errors___media_upload_error_pb2___MediaUploadErrorEnum.MediaUploadErrorValue = ...
    media_file_error: google___ads___googleads___v6___errors___media_file_error_pb2___MediaFileErrorEnum.MediaFileErrorValue = ...
    multiplier_error: google___ads___googleads___v6___errors___multiplier_error_pb2___MultiplierErrorEnum.MultiplierErrorValue = ...
    new_resource_creation_error: google___ads___googleads___v6___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum.NewResourceCreationErrorValue = ...
    not_empty_error: google___ads___googleads___v6___errors___not_empty_error_pb2___NotEmptyErrorEnum.NotEmptyErrorValue = ...
    null_error: google___ads___googleads___v6___errors___null_error_pb2___NullErrorEnum.NullErrorValue = ...
    operator_error: google___ads___googleads___v6___errors___operator_error_pb2___OperatorErrorEnum.OperatorErrorValue = ...
    range_error: google___ads___googleads___v6___errors___range_error_pb2___RangeErrorEnum.RangeErrorValue = ...
    recommendation_error: google___ads___googleads___v6___errors___recommendation_error_pb2___RecommendationErrorEnum.RecommendationErrorValue = ...
    region_code_error: google___ads___googleads___v6___errors___region_code_error_pb2___RegionCodeErrorEnum.RegionCodeErrorValue = ...
    setting_error: google___ads___googleads___v6___errors___setting_error_pb2___SettingErrorEnum.SettingErrorValue = ...
    string_format_error: google___ads___googleads___v6___errors___string_format_error_pb2___StringFormatErrorEnum.StringFormatErrorValue = ...
    string_length_error: google___ads___googleads___v6___errors___string_length_error_pb2___StringLengthErrorEnum.StringLengthErrorValue = ...
    operation_access_denied_error: google___ads___googleads___v6___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum.OperationAccessDeniedErrorValue = ...
    resource_access_denied_error: google___ads___googleads___v6___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum.ResourceAccessDeniedErrorValue = ...
    resource_count_limit_exceeded_error: google___ads___googleads___v6___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue = ...
    youtube_video_registration_error: google___ads___googleads___v6___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationErrorValue = ...
    ad_group_bid_modifier_error: google___ads___googleads___v6___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum.AdGroupBidModifierErrorValue = ...
    context_error: google___ads___googleads___v6___errors___context_error_pb2___ContextErrorEnum.ContextErrorValue = ...
    field_error: google___ads___googleads___v6___errors___field_error_pb2___FieldErrorEnum.FieldErrorValue = ...
    shared_set_error: google___ads___googleads___v6___errors___shared_set_error_pb2___SharedSetErrorEnum.SharedSetErrorValue = ...
    shared_criterion_error: google___ads___googleads___v6___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum.SharedCriterionErrorValue = ...
    campaign_shared_set_error: google___ads___googleads___v6___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum.CampaignSharedSetErrorValue = ...
    conversion_action_error: google___ads___googleads___v6___errors___conversion_action_error_pb2___ConversionActionErrorEnum.ConversionActionErrorValue = ...
    conversion_adjustment_upload_error: google___ads___googleads___v6___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue = ...
    conversion_upload_error: google___ads___googleads___v6___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum.ConversionUploadErrorValue = ...
    header_error: google___ads___googleads___v6___errors___header_error_pb2___HeaderErrorEnum.HeaderErrorValue = ...
    database_error: google___ads___googleads___v6___errors___database_error_pb2___DatabaseErrorEnum.DatabaseErrorValue = ...
    policy_finding_error: google___ads___googleads___v6___errors___policy_finding_error_pb2___PolicyFindingErrorEnum.PolicyFindingErrorValue = ...
    enum_error: google___ads___googleads___v6___errors___enum_error_pb2___EnumErrorEnum.EnumErrorValue = ...
    keyword_plan_error: google___ads___googleads___v6___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum.KeywordPlanErrorValue = ...
    keyword_plan_campaign_error: google___ads___googleads___v6___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue = ...
    keyword_plan_campaign_keyword_error: google___ads___googleads___v6___errors___keyword_plan_campaign_keyword_error_pb2___KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordErrorValue = ...
    keyword_plan_ad_group_error: google___ads___googleads___v6___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupErrorValue = ...
    keyword_plan_ad_group_keyword_error: google___ads___googleads___v6___errors___keyword_plan_ad_group_keyword_error_pb2___KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue = ...
    keyword_plan_idea_error: google___ads___googleads___v6___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum.KeywordPlanIdeaErrorValue = ...
    account_budget_proposal_error: google___ads___googleads___v6___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum.AccountBudgetProposalErrorValue = ...
    user_list_error: google___ads___googleads___v6___errors___user_list_error_pb2___UserListErrorEnum.UserListErrorValue = ...
    change_event_error: google___ads___googleads___v6___errors___change_event_error_pb2___ChangeEventErrorEnum.ChangeEventErrorValue = ...
    change_status_error: google___ads___googleads___v6___errors___change_status_error_pb2___ChangeStatusErrorEnum.ChangeStatusErrorValue = ...
    feed_error: google___ads___googleads___v6___errors___feed_error_pb2___FeedErrorEnum.FeedErrorValue = ...
    geo_target_constant_suggestion_error: google___ads___googleads___v6___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue = ...
    campaign_draft_error: google___ads___googleads___v6___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum.CampaignDraftErrorValue = ...
    feed_item_error: google___ads___googleads___v6___errors___feed_item_error_pb2___FeedItemErrorEnum.FeedItemErrorValue = ...
    label_error: google___ads___googleads___v6___errors___label_error_pb2___LabelErrorEnum.LabelErrorValue = ...
    billing_setup_error: google___ads___googleads___v6___errors___billing_setup_error_pb2___BillingSetupErrorEnum.BillingSetupErrorValue = ...
    customer_client_link_error: google___ads___googleads___v6___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue = ...
    customer_manager_link_error: google___ads___googleads___v6___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue = ...
    feed_mapping_error: google___ads___googleads___v6___errors___feed_mapping_error_pb2___FeedMappingErrorEnum.FeedMappingErrorValue = ...
    customer_feed_error: google___ads___googleads___v6___errors___customer_feed_error_pb2___CustomerFeedErrorEnum.CustomerFeedErrorValue = ...
    ad_group_feed_error: google___ads___googleads___v6___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum.AdGroupFeedErrorValue = ...
    campaign_feed_error: google___ads___googleads___v6___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum.CampaignFeedErrorValue = ...
    custom_interest_error: google___ads___googleads___v6___errors___custom_interest_error_pb2___CustomInterestErrorEnum.CustomInterestErrorValue = ...
    campaign_experiment_error: google___ads___googleads___v6___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum.CampaignExperimentErrorValue = ...
    extension_feed_item_error: google___ads___googleads___v6___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue = ...
    ad_parameter_error: google___ads___googleads___v6___errors___ad_parameter_error_pb2___AdParameterErrorEnum.AdParameterErrorValue = ...
    feed_item_validation_error: google___ads___googleads___v6___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationErrorValue = ...
    extension_setting_error: google___ads___googleads___v6___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum.ExtensionSettingErrorValue = ...
    feed_item_set_error: google___ads___googleads___v6___errors___feed_item_set_error_pb2___FeedItemSetErrorEnum.FeedItemSetErrorValue = ...
    feed_item_set_link_error: google___ads___googleads___v6___errors___feed_item_set_link_error_pb2___FeedItemSetLinkErrorEnum.FeedItemSetLinkErrorValue = ...
    feed_item_target_error: google___ads___googleads___v6___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum.FeedItemTargetErrorValue = ...
    policy_violation_error: google___ads___googleads___v6___errors___policy_violation_error_pb2___PolicyViolationErrorEnum.PolicyViolationErrorValue = ...
    partial_failure_error: google___ads___googleads___v6___errors___partial_failure_error_pb2___PartialFailureErrorEnum.PartialFailureErrorValue = ...
    policy_validation_parameter_error: google___ads___googleads___v6___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue = ...
    size_limit_error: google___ads___googleads___v6___errors___size_limit_error_pb2___SizeLimitErrorEnum.SizeLimitErrorValue = ...
    offline_user_data_job_error: google___ads___googleads___v6___errors___offline_user_data_job_error_pb2___OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue = ...
    not_allowlisted_error: google___ads___googleads___v6___errors___not_allowlisted_error_pb2___NotAllowlistedErrorEnum.NotAllowlistedErrorValue = ...
    manager_link_error: google___ads___googleads___v6___errors___manager_link_error_pb2___ManagerLinkErrorEnum.ManagerLinkErrorValue = ...
    currency_code_error: google___ads___googleads___v6___errors___currency_code_error_pb2___CurrencyCodeErrorEnum.CurrencyCodeErrorValue = ...
    access_invitation_error: google___ads___googleads___v6___errors___access_invitation_error_pb2___AccessInvitationErrorEnum.AccessInvitationErrorValue = ...
    reach_plan_error: google___ads___googleads___v6___errors___reach_plan_error_pb2___ReachPlanErrorEnum.ReachPlanErrorValue = ...
    invoice_error: google___ads___googleads___v6___errors___invoice_error_pb2___InvoiceErrorEnum.InvoiceErrorValue = ...
    payments_account_error: google___ads___googleads___v6___errors___payments_account_error_pb2___PaymentsAccountErrorEnum.PaymentsAccountErrorValue = ...
    time_zone_error: google___ads___googleads___v6___errors___time_zone_error_pb2___TimeZoneErrorEnum.TimeZoneErrorValue = ...
    asset_link_error: google___ads___googleads___v6___errors___asset_link_error_pb2___AssetLinkErrorEnum.AssetLinkErrorValue = ...
    user_data_error: google___ads___googleads___v6___errors___user_data_error_pb2___UserDataErrorEnum.UserDataErrorValue = ...
    batch_job_error: google___ads___googleads___v6___errors___batch_job_error_pb2___BatchJobErrorEnum.BatchJobErrorValue = ...
    account_link_error: google___ads___googleads___v6___errors___account_link_error_pb2___AccountLinkErrorEnum.AccountLinkErrorValue = ...
    third_party_app_analytics_link_error: google___ads___googleads___v6___errors___third_party_app_analytics_link_error_pb2___ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue = ...
    customer_user_access_error: google___ads___googleads___v6___errors___customer_user_access_error_pb2___CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue = ...
    custom_audience_error: google___ads___googleads___v6___errors___custom_audience_error_pb2___CustomAudienceErrorEnum.CustomAudienceErrorValue = ...
    def __init__(
        self,
        *,
        request_error: typing___Optional[
            google___ads___googleads___v6___errors___request_error_pb2___RequestErrorEnum.RequestErrorValue
        ] = None,
        bidding_strategy_error: typing___Optional[
            google___ads___googleads___v6___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum.BiddingStrategyErrorValue
        ] = None,
        url_field_error: typing___Optional[
            google___ads___googleads___v6___errors___url_field_error_pb2___UrlFieldErrorEnum.UrlFieldErrorValue
        ] = None,
        list_operation_error: typing___Optional[
            google___ads___googleads___v6___errors___list_operation_error_pb2___ListOperationErrorEnum.ListOperationErrorValue
        ] = None,
        query_error: typing___Optional[
            google___ads___googleads___v6___errors___query_error_pb2___QueryErrorEnum.QueryErrorValue
        ] = None,
        mutate_error: typing___Optional[
            google___ads___googleads___v6___errors___mutate_error_pb2___MutateErrorEnum.MutateErrorValue
        ] = None,
        field_mask_error: typing___Optional[
            google___ads___googleads___v6___errors___field_mask_error_pb2___FieldMaskErrorEnum.FieldMaskErrorValue
        ] = None,
        authorization_error: typing___Optional[
            google___ads___googleads___v6___errors___authorization_error_pb2___AuthorizationErrorEnum.AuthorizationErrorValue
        ] = None,
        internal_error: typing___Optional[
            google___ads___googleads___v6___errors___internal_error_pb2___InternalErrorEnum.InternalErrorValue
        ] = None,
        quota_error: typing___Optional[
            google___ads___googleads___v6___errors___quota_error_pb2___QuotaErrorEnum.QuotaErrorValue
        ] = None,
        ad_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_error_pb2___AdErrorEnum.AdErrorValue
        ] = None,
        ad_group_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_group_error_pb2___AdGroupErrorEnum.AdGroupErrorValue
        ] = None,
        campaign_budget_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum.CampaignBudgetErrorValue
        ] = None,
        campaign_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_error_pb2___CampaignErrorEnum.CampaignErrorValue
        ] = None,
        authentication_error: typing___Optional[
            google___ads___googleads___v6___errors___authentication_error_pb2___AuthenticationErrorEnum.AuthenticationErrorValue
        ] = None,
        ad_group_criterion_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum.AdGroupCriterionErrorValue
        ] = None,
        ad_customizer_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum.AdCustomizerErrorValue
        ] = None,
        ad_group_ad_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum.AdGroupAdErrorValue
        ] = None,
        ad_sharing_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_sharing_error_pb2___AdSharingErrorEnum.AdSharingErrorValue
        ] = None,
        adx_error: typing___Optional[
            google___ads___googleads___v6___errors___adx_error_pb2___AdxErrorEnum.AdxErrorValue
        ] = None,
        asset_error: typing___Optional[
            google___ads___googleads___v6___errors___asset_error_pb2___AssetErrorEnum.AssetErrorValue
        ] = None,
        bidding_error: typing___Optional[
            google___ads___googleads___v6___errors___bidding_error_pb2___BiddingErrorEnum.BiddingErrorValue
        ] = None,
        campaign_criterion_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum.CampaignCriterionErrorValue
        ] = None,
        collection_size_error: typing___Optional[
            google___ads___googleads___v6___errors___collection_size_error_pb2___CollectionSizeErrorEnum.CollectionSizeErrorValue
        ] = None,
        country_code_error: typing___Optional[
            google___ads___googleads___v6___errors___country_code_error_pb2___CountryCodeErrorEnum.CountryCodeErrorValue
        ] = None,
        criterion_error: typing___Optional[
            google___ads___googleads___v6___errors___criterion_error_pb2___CriterionErrorEnum.CriterionErrorValue
        ] = None,
        customer_error: typing___Optional[
            google___ads___googleads___v6___errors___customer_error_pb2___CustomerErrorEnum.CustomerErrorValue
        ] = None,
        date_error: typing___Optional[
            google___ads___googleads___v6___errors___date_error_pb2___DateErrorEnum.DateErrorValue
        ] = None,
        date_range_error: typing___Optional[
            google___ads___googleads___v6___errors___date_range_error_pb2___DateRangeErrorEnum.DateRangeErrorValue
        ] = None,
        distinct_error: typing___Optional[
            google___ads___googleads___v6___errors___distinct_error_pb2___DistinctErrorEnum.DistinctErrorValue
        ] = None,
        feed_attribute_reference_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum.FeedAttributeReferenceErrorValue
        ] = None,
        function_error: typing___Optional[
            google___ads___googleads___v6___errors___function_error_pb2___FunctionErrorEnum.FunctionErrorValue
        ] = None,
        function_parsing_error: typing___Optional[
            google___ads___googleads___v6___errors___function_parsing_error_pb2___FunctionParsingErrorEnum.FunctionParsingErrorValue
        ] = None,
        id_error: typing___Optional[
            google___ads___googleads___v6___errors___id_error_pb2___IdErrorEnum.IdErrorValue
        ] = None,
        image_error: typing___Optional[
            google___ads___googleads___v6___errors___image_error_pb2___ImageErrorEnum.ImageErrorValue
        ] = None,
        language_code_error: typing___Optional[
            google___ads___googleads___v6___errors___language_code_error_pb2___LanguageCodeErrorEnum.LanguageCodeErrorValue
        ] = None,
        media_bundle_error: typing___Optional[
            google___ads___googleads___v6___errors___media_bundle_error_pb2___MediaBundleErrorEnum.MediaBundleErrorValue
        ] = None,
        media_upload_error: typing___Optional[
            google___ads___googleads___v6___errors___media_upload_error_pb2___MediaUploadErrorEnum.MediaUploadErrorValue
        ] = None,
        media_file_error: typing___Optional[
            google___ads___googleads___v6___errors___media_file_error_pb2___MediaFileErrorEnum.MediaFileErrorValue
        ] = None,
        multiplier_error: typing___Optional[
            google___ads___googleads___v6___errors___multiplier_error_pb2___MultiplierErrorEnum.MultiplierErrorValue
        ] = None,
        new_resource_creation_error: typing___Optional[
            google___ads___googleads___v6___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum.NewResourceCreationErrorValue
        ] = None,
        not_empty_error: typing___Optional[
            google___ads___googleads___v6___errors___not_empty_error_pb2___NotEmptyErrorEnum.NotEmptyErrorValue
        ] = None,
        null_error: typing___Optional[
            google___ads___googleads___v6___errors___null_error_pb2___NullErrorEnum.NullErrorValue
        ] = None,
        operator_error: typing___Optional[
            google___ads___googleads___v6___errors___operator_error_pb2___OperatorErrorEnum.OperatorErrorValue
        ] = None,
        range_error: typing___Optional[
            google___ads___googleads___v6___errors___range_error_pb2___RangeErrorEnum.RangeErrorValue
        ] = None,
        recommendation_error: typing___Optional[
            google___ads___googleads___v6___errors___recommendation_error_pb2___RecommendationErrorEnum.RecommendationErrorValue
        ] = None,
        region_code_error: typing___Optional[
            google___ads___googleads___v6___errors___region_code_error_pb2___RegionCodeErrorEnum.RegionCodeErrorValue
        ] = None,
        setting_error: typing___Optional[
            google___ads___googleads___v6___errors___setting_error_pb2___SettingErrorEnum.SettingErrorValue
        ] = None,
        string_format_error: typing___Optional[
            google___ads___googleads___v6___errors___string_format_error_pb2___StringFormatErrorEnum.StringFormatErrorValue
        ] = None,
        string_length_error: typing___Optional[
            google___ads___googleads___v6___errors___string_length_error_pb2___StringLengthErrorEnum.StringLengthErrorValue
        ] = None,
        operation_access_denied_error: typing___Optional[
            google___ads___googleads___v6___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum.OperationAccessDeniedErrorValue
        ] = None,
        resource_access_denied_error: typing___Optional[
            google___ads___googleads___v6___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum.ResourceAccessDeniedErrorValue
        ] = None,
        resource_count_limit_exceeded_error: typing___Optional[
            google___ads___googleads___v6___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue
        ] = None,
        youtube_video_registration_error: typing___Optional[
            google___ads___googleads___v6___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationErrorValue
        ] = None,
        ad_group_bid_modifier_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum.AdGroupBidModifierErrorValue
        ] = None,
        context_error: typing___Optional[
            google___ads___googleads___v6___errors___context_error_pb2___ContextErrorEnum.ContextErrorValue
        ] = None,
        field_error: typing___Optional[
            google___ads___googleads___v6___errors___field_error_pb2___FieldErrorEnum.FieldErrorValue
        ] = None,
        shared_set_error: typing___Optional[
            google___ads___googleads___v6___errors___shared_set_error_pb2___SharedSetErrorEnum.SharedSetErrorValue
        ] = None,
        shared_criterion_error: typing___Optional[
            google___ads___googleads___v6___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum.SharedCriterionErrorValue
        ] = None,
        campaign_shared_set_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum.CampaignSharedSetErrorValue
        ] = None,
        conversion_action_error: typing___Optional[
            google___ads___googleads___v6___errors___conversion_action_error_pb2___ConversionActionErrorEnum.ConversionActionErrorValue
        ] = None,
        conversion_adjustment_upload_error: typing___Optional[
            google___ads___googleads___v6___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue
        ] = None,
        conversion_upload_error: typing___Optional[
            google___ads___googleads___v6___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum.ConversionUploadErrorValue
        ] = None,
        header_error: typing___Optional[
            google___ads___googleads___v6___errors___header_error_pb2___HeaderErrorEnum.HeaderErrorValue
        ] = None,
        database_error: typing___Optional[
            google___ads___googleads___v6___errors___database_error_pb2___DatabaseErrorEnum.DatabaseErrorValue
        ] = None,
        policy_finding_error: typing___Optional[
            google___ads___googleads___v6___errors___policy_finding_error_pb2___PolicyFindingErrorEnum.PolicyFindingErrorValue
        ] = None,
        enum_error: typing___Optional[
            google___ads___googleads___v6___errors___enum_error_pb2___EnumErrorEnum.EnumErrorValue
        ] = None,
        keyword_plan_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum.KeywordPlanErrorValue
        ] = None,
        keyword_plan_campaign_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue
        ] = None,
        keyword_plan_campaign_keyword_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_campaign_keyword_error_pb2___KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordErrorValue
        ] = None,
        keyword_plan_ad_group_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupErrorValue
        ] = None,
        keyword_plan_ad_group_keyword_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_ad_group_keyword_error_pb2___KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue
        ] = None,
        keyword_plan_idea_error: typing___Optional[
            google___ads___googleads___v6___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum.KeywordPlanIdeaErrorValue
        ] = None,
        account_budget_proposal_error: typing___Optional[
            google___ads___googleads___v6___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum.AccountBudgetProposalErrorValue
        ] = None,
        user_list_error: typing___Optional[
            google___ads___googleads___v6___errors___user_list_error_pb2___UserListErrorEnum.UserListErrorValue
        ] = None,
        change_event_error: typing___Optional[
            google___ads___googleads___v6___errors___change_event_error_pb2___ChangeEventErrorEnum.ChangeEventErrorValue
        ] = None,
        change_status_error: typing___Optional[
            google___ads___googleads___v6___errors___change_status_error_pb2___ChangeStatusErrorEnum.ChangeStatusErrorValue
        ] = None,
        feed_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_error_pb2___FeedErrorEnum.FeedErrorValue
        ] = None,
        geo_target_constant_suggestion_error: typing___Optional[
            google___ads___googleads___v6___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue
        ] = None,
        campaign_draft_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum.CampaignDraftErrorValue
        ] = None,
        feed_item_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_item_error_pb2___FeedItemErrorEnum.FeedItemErrorValue
        ] = None,
        label_error: typing___Optional[
            google___ads___googleads___v6___errors___label_error_pb2___LabelErrorEnum.LabelErrorValue
        ] = None,
        billing_setup_error: typing___Optional[
            google___ads___googleads___v6___errors___billing_setup_error_pb2___BillingSetupErrorEnum.BillingSetupErrorValue
        ] = None,
        customer_client_link_error: typing___Optional[
            google___ads___googleads___v6___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue
        ] = None,
        customer_manager_link_error: typing___Optional[
            google___ads___googleads___v6___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue
        ] = None,
        feed_mapping_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_mapping_error_pb2___FeedMappingErrorEnum.FeedMappingErrorValue
        ] = None,
        customer_feed_error: typing___Optional[
            google___ads___googleads___v6___errors___customer_feed_error_pb2___CustomerFeedErrorEnum.CustomerFeedErrorValue
        ] = None,
        ad_group_feed_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum.AdGroupFeedErrorValue
        ] = None,
        campaign_feed_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum.CampaignFeedErrorValue
        ] = None,
        custom_interest_error: typing___Optional[
            google___ads___googleads___v6___errors___custom_interest_error_pb2___CustomInterestErrorEnum.CustomInterestErrorValue
        ] = None,
        campaign_experiment_error: typing___Optional[
            google___ads___googleads___v6___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum.CampaignExperimentErrorValue
        ] = None,
        extension_feed_item_error: typing___Optional[
            google___ads___googleads___v6___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue
        ] = None,
        ad_parameter_error: typing___Optional[
            google___ads___googleads___v6___errors___ad_parameter_error_pb2___AdParameterErrorEnum.AdParameterErrorValue
        ] = None,
        feed_item_validation_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationErrorValue
        ] = None,
        extension_setting_error: typing___Optional[
            google___ads___googleads___v6___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum.ExtensionSettingErrorValue
        ] = None,
        feed_item_set_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_item_set_error_pb2___FeedItemSetErrorEnum.FeedItemSetErrorValue
        ] = None,
        feed_item_set_link_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_item_set_link_error_pb2___FeedItemSetLinkErrorEnum.FeedItemSetLinkErrorValue
        ] = None,
        feed_item_target_error: typing___Optional[
            google___ads___googleads___v6___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum.FeedItemTargetErrorValue
        ] = None,
        policy_violation_error: typing___Optional[
            google___ads___googleads___v6___errors___policy_violation_error_pb2___PolicyViolationErrorEnum.PolicyViolationErrorValue
        ] = None,
        partial_failure_error: typing___Optional[
            google___ads___googleads___v6___errors___partial_failure_error_pb2___PartialFailureErrorEnum.PartialFailureErrorValue
        ] = None,
        policy_validation_parameter_error: typing___Optional[
            google___ads___googleads___v6___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue
        ] = None,
        size_limit_error: typing___Optional[
            google___ads___googleads___v6___errors___size_limit_error_pb2___SizeLimitErrorEnum.SizeLimitErrorValue
        ] = None,
        offline_user_data_job_error: typing___Optional[
            google___ads___googleads___v6___errors___offline_user_data_job_error_pb2___OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue
        ] = None,
        not_allowlisted_error: typing___Optional[
            google___ads___googleads___v6___errors___not_allowlisted_error_pb2___NotAllowlistedErrorEnum.NotAllowlistedErrorValue
        ] = None,
        manager_link_error: typing___Optional[
            google___ads___googleads___v6___errors___manager_link_error_pb2___ManagerLinkErrorEnum.ManagerLinkErrorValue
        ] = None,
        currency_code_error: typing___Optional[
            google___ads___googleads___v6___errors___currency_code_error_pb2___CurrencyCodeErrorEnum.CurrencyCodeErrorValue
        ] = None,
        access_invitation_error: typing___Optional[
            google___ads___googleads___v6___errors___access_invitation_error_pb2___AccessInvitationErrorEnum.AccessInvitationErrorValue
        ] = None,
        reach_plan_error: typing___Optional[
            google___ads___googleads___v6___errors___reach_plan_error_pb2___ReachPlanErrorEnum.ReachPlanErrorValue
        ] = None,
        invoice_error: typing___Optional[
            google___ads___googleads___v6___errors___invoice_error_pb2___InvoiceErrorEnum.InvoiceErrorValue
        ] = None,
        payments_account_error: typing___Optional[
            google___ads___googleads___v6___errors___payments_account_error_pb2___PaymentsAccountErrorEnum.PaymentsAccountErrorValue
        ] = None,
        time_zone_error: typing___Optional[
            google___ads___googleads___v6___errors___time_zone_error_pb2___TimeZoneErrorEnum.TimeZoneErrorValue
        ] = None,
        asset_link_error: typing___Optional[
            google___ads___googleads___v6___errors___asset_link_error_pb2___AssetLinkErrorEnum.AssetLinkErrorValue
        ] = None,
        user_data_error: typing___Optional[
            google___ads___googleads___v6___errors___user_data_error_pb2___UserDataErrorEnum.UserDataErrorValue
        ] = None,
        batch_job_error: typing___Optional[
            google___ads___googleads___v6___errors___batch_job_error_pb2___BatchJobErrorEnum.BatchJobErrorValue
        ] = None,
        account_link_error: typing___Optional[
            google___ads___googleads___v6___errors___account_link_error_pb2___AccountLinkErrorEnum.AccountLinkErrorValue
        ] = None,
        third_party_app_analytics_link_error: typing___Optional[
            google___ads___googleads___v6___errors___third_party_app_analytics_link_error_pb2___ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue
        ] = None,
        customer_user_access_error: typing___Optional[
            google___ads___googleads___v6___errors___customer_user_access_error_pb2___CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue
        ] = None,
        custom_audience_error: typing___Optional[
            google___ads___googleads___v6___errors___custom_audience_error_pb2___CustomAudienceErrorEnum.CustomAudienceErrorValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_event_error",
            b"change_event_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_audience_error",
            b"custom_audience_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "customer_user_access_error",
            b"customer_user_access_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_set_error",
            b"feed_item_set_error",
            "feed_item_set_link_error",
            b"feed_item_set_link_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_event_error",
            b"change_event_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_audience_error",
            b"custom_audience_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "customer_user_access_error",
            b"customer_user_access_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_set_error",
            b"feed_item_set_error",
            "feed_item_set_link_error",
            b"feed_item_set_link_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["error_code", b"error_code"]
    ) -> typing_extensions___Literal[
        "request_error",
        "bidding_strategy_error",
        "url_field_error",
        "list_operation_error",
        "query_error",
        "mutate_error",
        "field_mask_error",
        "authorization_error",
        "internal_error",
        "quota_error",
        "ad_error",
        "ad_group_error",
        "campaign_budget_error",
        "campaign_error",
        "authentication_error",
        "ad_group_criterion_error",
        "ad_customizer_error",
        "ad_group_ad_error",
        "ad_sharing_error",
        "adx_error",
        "asset_error",
        "bidding_error",
        "campaign_criterion_error",
        "collection_size_error",
        "country_code_error",
        "criterion_error",
        "customer_error",
        "date_error",
        "date_range_error",
        "distinct_error",
        "feed_attribute_reference_error",
        "function_error",
        "function_parsing_error",
        "id_error",
        "image_error",
        "language_code_error",
        "media_bundle_error",
        "media_upload_error",
        "media_file_error",
        "multiplier_error",
        "new_resource_creation_error",
        "not_empty_error",
        "null_error",
        "operator_error",
        "range_error",
        "recommendation_error",
        "region_code_error",
        "setting_error",
        "string_format_error",
        "string_length_error",
        "operation_access_denied_error",
        "resource_access_denied_error",
        "resource_count_limit_exceeded_error",
        "youtube_video_registration_error",
        "ad_group_bid_modifier_error",
        "context_error",
        "field_error",
        "shared_set_error",
        "shared_criterion_error",
        "campaign_shared_set_error",
        "conversion_action_error",
        "conversion_adjustment_upload_error",
        "conversion_upload_error",
        "header_error",
        "database_error",
        "policy_finding_error",
        "enum_error",
        "keyword_plan_error",
        "keyword_plan_campaign_error",
        "keyword_plan_campaign_keyword_error",
        "keyword_plan_ad_group_error",
        "keyword_plan_ad_group_keyword_error",
        "keyword_plan_idea_error",
        "account_budget_proposal_error",
        "user_list_error",
        "change_event_error",
        "change_status_error",
        "feed_error",
        "geo_target_constant_suggestion_error",
        "campaign_draft_error",
        "feed_item_error",
        "label_error",
        "billing_setup_error",
        "customer_client_link_error",
        "customer_manager_link_error",
        "feed_mapping_error",
        "customer_feed_error",
        "ad_group_feed_error",
        "campaign_feed_error",
        "custom_interest_error",
        "campaign_experiment_error",
        "extension_feed_item_error",
        "ad_parameter_error",
        "feed_item_validation_error",
        "extension_setting_error",
        "feed_item_set_error",
        "feed_item_set_link_error",
        "feed_item_target_error",
        "policy_violation_error",
        "partial_failure_error",
        "policy_validation_parameter_error",
        "size_limit_error",
        "offline_user_data_job_error",
        "not_allowlisted_error",
        "manager_link_error",
        "currency_code_error",
        "access_invitation_error",
        "reach_plan_error",
        "invoice_error",
        "payments_account_error",
        "time_zone_error",
        "asset_link_error",
        "user_data_error",
        "batch_job_error",
        "account_link_error",
        "third_party_app_analytics_link_error",
        "customer_user_access_error",
        "custom_audience_error",
    ]: ...

type___ErrorCode = ErrorCode

class ErrorLocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FieldPathElement(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        field_name: typing___Text = ...
        index: builtin___int = ...
        def __init__(
            self,
            *,
            field_name: typing___Optional[typing___Text] = None,
            index: typing___Optional[builtin___int] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_index", b"_index", "index", b"index"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_index", b"_index", "field_name", b"field_name", "index", b"index"
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_index", b"_index"]
        ) -> typing_extensions___Literal["index"]: ...
    type___FieldPathElement = FieldPathElement
    @property
    def field_path_elements(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ErrorLocation.FieldPathElement
    ]: ...
    def __init__(
        self,
        *,
        field_path_elements: typing___Optional[
            typing___Iterable[type___ErrorLocation.FieldPathElement]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "field_path_elements", b"field_path_elements"
        ],
    ) -> None: ...

type___ErrorLocation = ErrorLocation

class ErrorDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    unpublished_error_code: typing___Text = ...
    @property
    def policy_violation_details(self) -> type___PolicyViolationDetails: ...
    @property
    def policy_finding_details(self) -> type___PolicyFindingDetails: ...
    @property
    def quota_error_details(self) -> type___QuotaErrorDetails: ...
    def __init__(
        self,
        *,
        unpublished_error_code: typing___Optional[typing___Text] = None,
        policy_violation_details: typing___Optional[
            type___PolicyViolationDetails
        ] = None,
        policy_finding_details: typing___Optional[type___PolicyFindingDetails] = None,
        quota_error_details: typing___Optional[type___QuotaErrorDetails] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
            "unpublished_error_code",
            b"unpublished_error_code",
        ],
    ) -> None: ...

type___ErrorDetails = ErrorDetails

class PolicyViolationDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    external_policy_description: typing___Text = ...
    external_policy_name: typing___Text = ...
    is_exemptible: builtin___bool = ...
    @property
    def key(
        self,
    ) -> google___ads___googleads___v6___common___policy_pb2___PolicyViolationKey: ...
    def __init__(
        self,
        *,
        external_policy_description: typing___Optional[typing___Text] = None,
        key: typing___Optional[
            google___ads___googleads___v6___common___policy_pb2___PolicyViolationKey
        ] = None,
        external_policy_name: typing___Optional[typing___Text] = None,
        is_exemptible: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["key", b"key"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "external_policy_description",
            b"external_policy_description",
            "external_policy_name",
            b"external_policy_name",
            "is_exemptible",
            b"is_exemptible",
            "key",
            b"key",
        ],
    ) -> None: ...

type___PolicyViolationDetails = PolicyViolationDetails

class PolicyFindingDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "policy_topic_entries", b"policy_topic_entries"
        ],
    ) -> None: ...

type___PolicyFindingDetails = PolicyFindingDetails

class QuotaErrorDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    QuotaRateScopeValue = typing___NewType("QuotaRateScopeValue", builtin___int)
    type___QuotaRateScopeValue = QuotaRateScopeValue
    QuotaRateScope: _QuotaRateScope
    class _QuotaRateScope(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            QuotaErrorDetails.QuotaRateScopeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 0)
        UNKNOWN = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 1)
        ACCOUNT = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 2)
        DEVELOPER = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 3)
    UNSPECIFIED = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 0)
    UNKNOWN = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 1)
    ACCOUNT = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 2)
    DEVELOPER = typing___cast(QuotaErrorDetails.QuotaRateScopeValue, 3)
    type___QuotaRateScope = QuotaRateScope

    rate_scope: type___QuotaErrorDetails.QuotaRateScopeValue = ...
    rate_name: typing___Text = ...
    @property
    def retry_delay(self) -> google___protobuf___duration_pb2___Duration: ...
    def __init__(
        self,
        *,
        rate_scope: typing___Optional[
            type___QuotaErrorDetails.QuotaRateScopeValue
        ] = None,
        rate_name: typing___Optional[typing___Text] = None,
        retry_delay: typing___Optional[
            google___protobuf___duration_pb2___Duration
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["retry_delay", b"retry_delay"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "rate_name",
            b"rate_name",
            "rate_scope",
            b"rate_scope",
            "retry_delay",
            b"retry_delay",
        ],
    ) -> None: ...

type___QuotaErrorDetails = QuotaErrorDetails



from typing import Any

class GroupPlacementViewServiceStub:
    GetGroupPlacementView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GroupPlacementViewServiceServicer:
    def GetGroupPlacementView(self, request: Any, context: Any) -> None: ...

def add_GroupPlacementViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BiddingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BiddingErrorValue = typing___NewType("BiddingErrorValue", builtin___int)
    type___BiddingErrorValue = BiddingErrorValue
    BiddingError: _BiddingError
    class _BiddingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BiddingErrorEnum.BiddingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BiddingErrorEnum.BiddingErrorValue, 0)
        UNKNOWN = typing___cast(BiddingErrorEnum.BiddingErrorValue, 1)
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 2
        )
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 7
        )
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 10
        )
        INVALID_BIDDING_STRATEGY_TYPE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 14
        )
        INVALID_BID = typing___cast(BiddingErrorEnum.BiddingErrorValue, 17)
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 18
        )
        CONVERSION_TRACKING_NOT_ENABLED = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 19
        )
        NOT_ENOUGH_CONVERSIONS = typing___cast(BiddingErrorEnum.BiddingErrorValue, 20)
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 21
        )
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 23
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 24
        )
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 25
        )
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 26
        )
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 27
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 28
        )
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 29
        )
        BID_TOO_SMALL = typing___cast(BiddingErrorEnum.BiddingErrorValue, 30)
        BID_TOO_BIG = typing___cast(BiddingErrorEnum.BiddingErrorValue, 31)
        BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 32
        )
        INVALID_DOMAIN_NAME = typing___cast(BiddingErrorEnum.BiddingErrorValue, 33)
        NOT_COMPATIBLE_WITH_PAYMENT_MODE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 34
        )
        NOT_COMPATIBLE_WITH_BUDGET_TYPE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 35
        )
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 36
        )
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = typing___cast(
            BiddingErrorEnum.BiddingErrorValue, 37
        )
    UNSPECIFIED = typing___cast(BiddingErrorEnum.BiddingErrorValue, 0)
    UNKNOWN = typing___cast(BiddingErrorEnum.BiddingErrorValue, 1)
    BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 2
    )
    CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 7
    )
    INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 10
    )
    INVALID_BIDDING_STRATEGY_TYPE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 14
    )
    INVALID_BID = typing___cast(BiddingErrorEnum.BiddingErrorValue, 17)
    BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 18
    )
    CONVERSION_TRACKING_NOT_ENABLED = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 19
    )
    NOT_ENOUGH_CONVERSIONS = typing___cast(BiddingErrorEnum.BiddingErrorValue, 20)
    CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 21
    )
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 23
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 24
    )
    PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 25
    )
    PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 26
    )
    BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 27
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 28
    )
    BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 29
    )
    BID_TOO_SMALL = typing___cast(BiddingErrorEnum.BiddingErrorValue, 30)
    BID_TOO_BIG = typing___cast(BiddingErrorEnum.BiddingErrorValue, 31)
    BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 32
    )
    INVALID_DOMAIN_NAME = typing___cast(BiddingErrorEnum.BiddingErrorValue, 33)
    NOT_COMPATIBLE_WITH_PAYMENT_MODE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 34
    )
    NOT_COMPATIBLE_WITH_BUDGET_TYPE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 35
    )
    NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 36
    )
    BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = typing___cast(
        BiddingErrorEnum.BiddingErrorValue, 37
    )
    type___BiddingError = BiddingError
    def __init__(self,) -> None: ...

type___BiddingErrorEnum = BiddingErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BillingSetupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BillingSetupErrorValue = typing___NewType("BillingSetupErrorValue", builtin___int)
    type___BillingSetupErrorValue = BillingSetupErrorValue
    BillingSetupError: _BillingSetupError
    class _BillingSetupError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BillingSetupErrorEnum.BillingSetupErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 0)
        UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 1)
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 2
        )
        CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 3
        )
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 4
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 5
        )
        INVALID_PAYMENTS_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 6
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 7
        )
        INVALID_START_TIME_TYPE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 8
        )
        THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 9
        )
        BILLING_SETUP_IN_PROGRESS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 10
        )
        NO_SIGNUP_PERMISSION = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 11
        )
        CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 12
        )
        PAYMENTS_PROFILE_NOT_FOUND = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 13
        )
        PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 14
        )
        PAYMENTS_PROFILE_INELIGIBLE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 15
        )
        PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 16
        )
        CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 17
        )
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 19
        )
    UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 0)
    UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 1)
    CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 2
    )
    CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 3
    )
    CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 4
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 5
    )
    INVALID_PAYMENTS_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 6
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 7
    )
    INVALID_START_TIME_TYPE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 8
    )
    THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 9
    )
    BILLING_SETUP_IN_PROGRESS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 10
    )
    NO_SIGNUP_PERMISSION = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 11
    )
    CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 12
    )
    PAYMENTS_PROFILE_NOT_FOUND = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 13
    )
    PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 14
    )
    PAYMENTS_PROFILE_INELIGIBLE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 15
    )
    PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 16
    )
    CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 17
    )
    PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 19
    )
    type___BillingSetupError = BillingSetupError
    def __init__(self,) -> None: ...

type___BillingSetupErrorEnum = BillingSetupErrorEnum
